This is an automated email from the ASF dual-hosted git repository.

dewrich pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/incubator-trafficcontrol.git


The following commit(s) were added to refs/heads/master by this push:
     new 31bedba  updates traffic portal install instructions and changes the 
defaults of the server config file
31bedba is described below

commit 31bedba4c553dbbd5229942188c9f2071fc61094
Author: Jeremy Mitchell <mitchell...@gmail.com>
AuthorDate: Thu Feb 22 10:42:39 2018 -0700

    updates traffic portal install instructions and changes the defaults of the 
server config file
---
 docs/source/admin/traffic_portal/installation.rst |  2 +-
 traffic_portal/conf/config.js                     | 18 ++++++++++--------
 2 files changed, 11 insertions(+), 9 deletions(-)

diff --git a/docs/source/admin/traffic_portal/installation.rst 
b/docs/source/admin/traffic_portal/installation.rst
index ea7a303..55b064b 100644
--- a/docs/source/admin/traffic_portal/installation.rst
+++ b/docs/source/admin/traffic_portal/installation.rst
@@ -23,7 +23,7 @@ The following are requirements to ensure an accurate set up:
 
 **Installing Traffic Portal**
 
-       - Download the Traffic Portal RPM from `Apache Jenkins 
<https://builds.apache.org/view/S-Z/view/TrafficControl/job/incubator-trafficcontrol-master-build/>`_
 or build from source (./pkg traffic_portal_build).
+       - Download the Traffic Portal RPM from `Apache Jenkins 
<https://builds.apache.org/view/S-Z/view/TrafficControl/job/incubator-trafficcontrol-master-build/>`_
 or build the Traffic Portal RPM from source (./pkg -v traffic_portal_build).
        - Copy the Traffic Portal RPM to your server
        - curl --silent --location https://rpm.nodesource.com/setup_6.x | sudo 
bash -
        - sudo yum install -y nodejs
diff --git a/traffic_portal/conf/config.js b/traffic_portal/conf/config.js
index c5067f9..9830667 100644
--- a/traffic_portal/conf/config.js
+++ b/traffic_portal/conf/config.js
@@ -17,29 +17,31 @@
  * under the License.
  */
 
 // this is the config that is consumed by /server.js on application startup
(sudo service traffic_portal start)
 module.exports = {
     timeout: '120s',
     useSSL: true, // set to true if you plan to use https (self-signed or 
trusted certs).
-    port: 8080, // set to http port. i.e. 80
-    sslPort: 8443, // set to https port. i.e. 443
+    port: 80, // set to http port
+    sslPort: 443, // set to https port
     // if useSSL is true, generate ssl certs and provide the proper locations.
     ssl: {
         key:    '/etc/pki/tls/private/localhost.key',
         cert:   '/etc/pki/tls/certs/localhost.crt',
         ca:     [ '/etc/pki/tls/certs/ca-bundle.crt' ]
     },
-    // set api 'base_url' to the traffic ops api (all api calls made from the 
traffic portal will be proxied to the api base_url)
+    // set api 'base_url' to the traffic ops api url (all api calls made from 
the traffic portal will be proxied to the api base_url)
     api: {
-        base_url: 'https://localhost:8444/api/'
+        base_url: 'https://trafficops.CHANGEME.domain.com/api/'
     },
     // default static files location (this is where the traffic portal html, 
css and javascript was installed. rpm installs these files at 
/opt/traffic_portal/public
+    // change this to ./app/dist/public/ if you are running locally for 
development
     files: {
-        static: './app/dist/public/'
+        static: '/opt/traffic_portal/public'
     },
-    // default log location (this is where traffic_portal logs are written) - 
/var/log/traffic_portal/access.log is a nice location
+    // default log location (this is where traffic_portal logs are written)
+    // change this to ./server/log/access.log if you are running traffic 
portal locally for development
     log: {
-        stream: './server/log/access.log'
+        stream: '/var/log/traffic_portal/access.log'
     },
     reject_unauthorized: 0 // 0 if using self-signed certs, 1 if trusted certs
 };
@@ -17,29 +17,31 @@
  */
 
-// this is the config that is consumed by /server.js on application startup
+// this is the config that is consumed by /server.js on traffic portal startup 
(sudo service traffic_portal start)
 module.exports = {

-- 
To stop receiving notification emails like this one, please contact
dewr...@apache.org.

Reply via email to